@@ -3,15 +3,13 @@ from typing import Protocol
 
 
 class NamingCase(Protocol):
-    __slots__ = ()
-
     def __call__(self, name: str) -> str:
         ...
 
 
 @dataclasses.dataclass(frozen=True, slots=True, kw_only=True)
-class CapitalCamelCase(NamingCase):
-    capitalize_words: set[str]
+class CapitalCamelCase:
+    capitalize_words: frozenset[str]
 
     def __call__(self, name: str) -> str:
         return "".join(self._process_word(word) for word in name.split("_") if word)
@@ -25,8 +23,8 @@ class CapitalCamelCase(NamingCase):
 
 
 @dataclasses.dataclass(frozen=True, slots=True, kw_only=True)
-class CamelCase(NamingCase):
-    capitalize_words: set[str]
+class CamelCase:
+    capitalize_words: frozenset[str]
 
     def __call__(self, name: str) -> str:
         words = [word for word in name.split("_") if word]
@@ -41,10 +39,11 @@ class CamelCase(NamingCase):
 
 
 @dataclasses.dataclass(frozen=True, slots=True, kw_only=True)
-class _Default(NamingCase):
-    pass
+class _Default:
+    def __call__(self, name: str) -> str:
+        return name
 
 
-CAPITAL_CAMEL_CASE = CapitalCamelCase(capitalize_words=set())
-CAMEL_CASE = CamelCase(capitalize_words=set())
+CAPITAL_CAMEL_CASE = CapitalCamelCase(capitalize_words=frozenset())
+CAMEL_CASE = CamelCase(capitalize_words=frozenset())
 DEFAULT_CASE = _Default()
